@@ -1,13 +1,10 @@
-// Copyright (c) 2023 Yuki Kimoto
-// MIT License
-
 #ifndef SPVM_FIELD_ACCESS_H
 #define SPVM_FIELD_ACCESS_H
 
 #include "spvm_typedecl.h"
 
 struct spvm_field_access {
-  SPVM_OP* op_invocant;
+  SPVM_OP* op_term;
   SPVM_OP* op_name;
   SPVM_FIELD* field;
   int32_t inline_expansion;
