@@ -4,7 +4,7 @@ package SPVM::Regex;
 
 =head1 NAME
 
-SPVM::Regex - Regex in SPVM | Regular expression
+SPVM::Regex - Regular expression
 
 =head1 SYNOPSYS
   
@@ -85,11 +85,29 @@ SPVM::Regex - Regex in SPVM | Regular expression
       return "ABC" . $re->captures->[0] . "PQRS";
     });
   }
-  
+
+  # . - single line mode
+  {
+    my $re = Regex->new("(.+)", "s");
+    my $target = "abc\ndef";
+    
+    my $match = $re->match($target, 0);
+    
+    unless ($match) {
+      return 0;
+    }
+    
+    unless ($re->captures->[0] eq "abc\ndef") {
+      return 0;
+    }
+  }
+
 =head1 DESCRIPTION
 
 L<Regex|SPVM::Regex> provides regular expression functions.
 
+This module is very unstable compared to other modules. So many changes will be performed.
+
 =head1 REGULAR EXPRESSION SYNTAX
 
 L<Regex|SPVM::Regex> provides the methodset of Perl regular expression. The target string and regex string is interpretted as UTF-8 string.
@@ -149,16 +167,21 @@ If 0 width quantifir is between two same set of characters after a quantifier, i
 
 =head2 new
 
-  my $re = Regex->new("^ab+c");
+  static method new : Regex ($re_str_and_options : string[]...)
 
 Create a new L<Regex|SPVM::Regex> object and compile the regex.
 
-=head2 new_with_options
-
+  my $re = Regex->new("^ab+c");
   my $re = Regex->new("^ab+c", "s");
 
+=head2 new_with_options
+
+  static method new_with_options : Regex ($re_str : string, $option_chars : string) {
+  
 Create a new L<Regex|SPVM::Regex> object and compile the regex with the options.
 
+  my $re = Regex->new("^ab+c", "s");
+
 =head1 INSTANCE METHODS
 
 =head2 captures
@@ -207,7 +230,7 @@ Replace the target string specified with the start byte offset with replace stri
 
   method replace_cb  : string ($target : string, $target_offset : int, $replace_cb : Regex::Replacer)
 
-Replace the target string specified with the start byte offset with replace callback. The callback must have "replace_to" method defined in L<Regex::Replacer|SPVM::Regex::Replacer>.
+Replace the target string specified with the start byte offset with replace callback. The callback must have the L<Regex::Replacer|SPVM::Regex::Replacer> interface..
 
 =head2 replace_all
 
@@ -219,4 +242,64 @@ Replace all of the target strings specified with the start byte offset with repl
 
   method replace_all_cb  : string ($target : string, $target_offset : int, $replace_cb : Regex::Replacer)
 
-Replace all of the target strings specified with the start byte offset with replace callback. The callback must have "replace_to" method defined in L<Regex::Replacer|SPVM::Regex::Replacer>.
+Replace all of the target strings specified with the start byte offset with replace callback. The callback must have the L<Regex::Replacer|SPVM::Regex::Replacer> interface.
+
+=head2 cap1
+
+  method cap1 : string ()
+
+The alias for C<$re->captures->[0]>.
+
+=head2 cap2
+
+  method cap2 : string ()
+
+The alias for C<$re->captures->[1]>.
+
+=head2 cap3
+
+  method cap3 : string ()
+
+The alias for C<$re->captures->[2]>.
+
+=head2 cap4
+
+  method cap4 : string ()
+
+The alias for C<$re->captures->[3]>.
+
+=head2 cap5
+
+  method cap5 : string ()
+
+The alias for C<$re->captures->[4]>.
+
+=head2 cap6
+
+  method cap6 : string ()
+
+The alias for C<$re->captures->[5]>.
+
+=head2 cap7
+
+  method cap7 : string ()
+
+The alias for C<$re->captures->[6]>.
+
+=head2 cap8
+
+  method cap8 : string ()
+
+The alias for C<$re->captures->[7]>.
+
+=head2 cap9
+
+  method cap9 : string ()
+
+The alias for C<$re->captures->[8]>.
+
+=head2 cap10
+
+  method cap10 : string ()
+
+The alias for C<$re->captures->[9]>.
